ResolveGroupJoinRequest

Struct ResolveGroupJoinRequest 

pub struct ResolveGroupJoinRequest<C, M, R = Standard> { /* private fields */ }
Fluent builder constructing a request to ResolveGroupJoinRequest.

Resolves a join request for a given group.

Implementations

Source

impl<C, M, R> ResolveGroupJoinRequest<C, M, R>

pub async fn send( self, ) -> Result<ResolveGroupJoinRequestOutput, SdkError<ResolveGroupJoinRequestError>>
where R::Policy: SmithyRetryPolicy<ResolveGroupJoinRequestInputOperationOutputAlias, ResolveGroupJoinRequestOutput, ResolveGroupJoinRequestError, ResolveGroupJoinRequestInputOperationRetryAlias>,

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn group_id(self, input: impl Into<String>) -> Self

A universally unique identifier.

pub fn set_group_id(self, input: Option<String>) -> Self

A universally unique identifier.

pub fn identity_id(self, input: impl Into<String>) -> Self

A universally unique identifier.

pub fn set_identity_id(self, input: Option<String>) -> Self

A universally unique identifier.

pub fn resolution(self, input: bool) -> Self

pub fn set_resolution(self, input: Option<bool>) -> Self