pub struct CreateGroupInvite<C, M, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to CreateGroupInvite.
Creates a group invite. Can be shared with other identities to let them join this group.
Implementations
Sourceimpl<C, M, R> CreateGroupInvite<C, M, R>
impl<C, M, R> CreateGroupInvite<C, M, R>
Sourcepub async fn send(
self,
) -> Result<CreateGroupInviteOutput, SdkError<CreateGroupInviteError>>where
R::Policy: SmithyRetryPolicy<CreateGroupInviteInputOperationOutputAlias, CreateGroupInviteOutput, CreateGroupInviteError, CreateGroupInviteInputOperationRetryAlias>,
pub async fn send(
self,
) -> Result<CreateGroupInviteOutput, SdkError<CreateGroupInviteError>>where
R::Policy: SmithyRetryPolicy<CreateGroupInviteInputOperationOutputAlias, CreateGroupInviteOutput, CreateGroupInviteError, CreateGroupInviteInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn set_group_id(self, input: Option<String>) -> Self
pub fn set_group_id(self, input: Option<String>) -> Self
A universally unique identifier.
Sourcepub fn ttl(self, input: i64) -> Self
pub fn ttl(self, input: i64) -> Self
How long until the group invite expires (in milliseconds).
Sourcepub fn set_ttl(self, input: Option<i64>) -> Self
pub fn set_ttl(self, input: Option<i64>) -> Self
How long until the group invite expires (in milliseconds).
Sourcepub fn set_use_count(self, input: Option<i64>) -> Self
pub fn set_use_count(self, input: Option<i64>) -> Self
How many times the group invite can be used.