pub struct ResolveGroupJoinRequest<C, M, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to ResolveGroupJoinRequest.
Resolves a join request for a given group.
Implementations
Sourceimpl<C, M, R> ResolveGroupJoinRequest<C, M, R>
impl<C, M, R> ResolveGroupJoinRequest<C, M, R>
Sourcepub async fn send(
self,
) -> Result<ResolveGroupJoinRequestOutput, SdkError<ResolveGroupJoinRequestError>>where
R::Policy: SmithyRetryPolicy<ResolveGroupJoinRequestInputOperationOutputAlias, ResolveGroupJoinRequestOutput, ResolveGroupJoinRequestError, ResolveGroupJoinRequestInputOperationRetryAlias>,
pub async fn send(
self,
) -> Result<ResolveGroupJoinRequestOutput, SdkError<ResolveGroupJoinRequestError>>where
R::Policy: SmithyRetryPolicy<ResolveGroupJoinRequestInputOperationOutputAlias, ResolveGroupJoinRequestOutput, ResolveGroupJoinRequestError, ResolveGroupJoinRequestInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn set_group_id(self, input: Option<String>) -> Self
pub fn set_group_id(self, input: Option<String>) -> Self
A universally unique identifier.
Sourcepub fn identity_id(self, input: impl Into<String>) -> Self
pub fn identity_id(self, input: impl Into<String>) -> Self
A universally unique identifier.
Sourcepub fn set_identity_id(self, input: Option<String>) -> Self
pub fn set_identity_id(self, input: Option<String>) -> Self
A universally unique identifier.
pub fn resolution(self, input: bool) -> Self
pub fn set_resolution(self, input: Option<bool>) -> Self